@@ -15,7 +15,7 @@ source_file <- function(path, env = test_env(), chdir = TRUE,
   stopifnot(file.exists(path))
   stopifnot(is.environment(env))
 
-  lines <- read_lines(path)
+  lines <- brio::read_lines(path)
   srcfile <- srcfilecopy(path, lines, file.info(path)[1, "mtime"], isFile = TRUE)
 
   ## We need to parse from a connection, because parse() has a bug,
@@ -36,7 +36,15 @@ source_file <- function(path, env = test_env(), chdir = TRUE,
   if (wrap) {
     invisible(test_code(NULL, exprs, env))
   } else {
-    invisible(eval(exprs, env))
+    withCallingHandlers(
+      invisible(eval(exprs, env)),
+      error = function(err) {
+        abort(
+          paste0("In path: ", encodeString(path, quote = '"')),
+          parent = err
+        )
+      }
+    )
   }
 }
 
@@ -45,7 +53,9 @@ source_file <- function(path, env = test_env(), chdir = TRUE,
 source_dir <- function(path, pattern = "\\.[rR]$", env = test_env(),
                        chdir = TRUE, wrap = TRUE) {
   files <- normalizePath(sort(dir(path, pattern, full.names = TRUE)))
-  lapply(files, source_file, env = env, chdir = chdir, wrap = wrap)
+  lapply(files, function(path) {
+    source_file(path, env = env, chdir = chdir, wrap = wrap)
+  })
 }
 
 #' @rdname source_file
