@@ -3,11 +3,11 @@ describe("describe", {
   it("can contain nested describe blocks", {
     describe("addition", {
       it("should be able to add two numbers", {
-        expect_equivalent(2, 1 + 1)
+        expect_equal(2, 1 + 1)
       })
       describe("sub feature", {
         it("should also work", {
-          expect_equivalent(2, 1 + 1)
+          expect_equal(2, 1 + 1)
         })
       })
     })
@@ -19,30 +19,22 @@ describe("describe", {
     })
   })
 
-  it("has to have a description for the block", {
-    expect_that(describe({
-    }), throws_error())
-    expect_that(describe("", {
-    }), throws_error())
-    expect_that(describe("test", {
-      it()
-    }), throws_error())
-    expect_that(describe("test", {
-      it("")
-    }), throws_error())
-  })
+  it("has to have a valid description for the block", {
+    expect_snapshot(error = TRUE, {
+      describe()
+      describe("")
+      describe(c("a", "b"))
 
-  it("has to have a description of length 1", {
-    expect_that(describe(c("a", "b"), {}), throws_error())
-    expect_that(describe("test", {
+      it()
+      it("")
       it(c("a", "b"))
-    }), throws_error())
+    })
   })
 
   someInternalVariable <- 1
   it("should be possible to use variables from outer environments", {
-    expect_equivalent(1, someExternalVariable)
-    expect_equivalent(1, someInternalVariable)
+    expect_equal(1, someExternalVariable)
+    expect_equal(1, someInternalVariable)
   })
 
   it("should not be possible to access variables from other specs (1)", {
